==> zio-aws-servicecatalog_2.13-5.17.151.2-sources.jar: zio/aws/servicecatalog/model/CreateTagOptionResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateTagOptionResponse(
    tagOptionDetail: Option[zio.aws.servicecatalog.model.TagOptionDetail] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse = {
    import CreateTagOptionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse
      .builder()
      .optionallyWith(tagOptionDetail.map(value => value.buildAwsValue()))(
        _.tagOptionDetail
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.CreateTagOptionResponse.ReadOnly =
    zio.aws.servicecatalog.model.CreateTagOptionResponse.wrap(buildAwsValue())
}
object CreateTagOptionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.CreateTagOptionResponse =
      zio.aws.servicecatalog.model
        .CreateTagOptionResponse(tagOptionDetail.map(value => value.asEditable))
    def tagOptionDetail
        : Option[zio.aws.servicecatalog.model.TagOptionDetail.ReadOnly]
    def getTagOptionDetail: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.TagOptionDetail.ReadOnly
    ] = AwsError.unwrapOptionField("tagOptionDetail", tagOptionDetail)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse
  ) extends zio.aws.servicecatalog.model.CreateTagOptionResponse.ReadOnly {
    override val tagOptionDetail
        : Option[zio.aws.servicecatalog.model.TagOptionDetail.ReadOnly] = scala
      .Option(impl.tagOptionDetail())
      .map(value => zio.aws.servicecatalog.model.TagOptionDetail.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse
  ): zio.aws.servicecatalog.model.CreateTagOptionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-6.20.103.2-sources.jar: zio/aws/servicecatalog/model/CreateTagOptionResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateTagOptionResponse(
    tagOptionDetail: Optional[zio.aws.servicecatalog.model.TagOptionDetail] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse = {
    import CreateTagOptionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse
      .builder()
      .optionallyWith(tagOptionDetail.map(value => value.buildAwsValue()))(
        _.tagOptionDetail
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.CreateTagOptionResponse.ReadOnly =
    zio.aws.servicecatalog.model.CreateTagOptionResponse.wrap(buildAwsValue())
}
object CreateTagOptionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.CreateTagOptionResponse =
      zio.aws.servicecatalog.model
        .CreateTagOptionResponse(tagOptionDetail.map(value => value.asEditable))
    def tagOptionDetail
        : Optional[zio.aws.servicecatalog.model.TagOptionDetail.ReadOnly]
    def getTagOptionDetail: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.TagOptionDetail.ReadOnly
    ] = AwsError.unwrapOptionField("tagOptionDetail", tagOptionDetail)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse
  ) extends zio.aws.servicecatalog.model.CreateTagOptionResponse.ReadOnly {
    override val tagOptionDetail
        : Optional[zio.aws.servicecatalog.model.TagOptionDetail.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tagOptionDetail())
        .map(value => zio.aws.servicecatalog.model.TagOptionDetail.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.CreateTagOptionResponse
  ): zio.aws.servicecatalog.model.CreateTagOptionResponse.ReadOnly =
    new Wrapper(impl)
}
